abacusai.feature_group_export_config — AbacusAI documentation

# `abacusai.feature_group_export_config`

## Module Contents

### Classes

`FeatureGroupExportConfig` | Export config (file connector or database connector information) for feature group exports

class abacusai.feature_group_export_config.FeatureGroupExportConfig(client, outputLocation=None, fileFormat=None, databaseConnectorId=None, objectName=None, writeMode=None, databaseFeatureMapping=None, idColumn=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Export config (file connector or database connector information) for feature group exports

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - outputLocation (str) – The File Connector location the feature group is being written to

    - fileFormat (str) – The file format being written to outputLocation

    - databaseConnectorId (str) – The database connector ID used

    - objectName (str) – The database connector’s object to write to

    - writeMode (str) – UPSERT or INSERT for writing to the database connector

    - databaseFeatureMapping (dict) – The column/feature pairs mapping the features to the database columns

    - idColumn (str) – The id column to use as the upsert key

  __repr__(self)

    Return repr(self).

  to_dict(self)

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict